@@ -53,6 +53,7 @@ parsers = [
     'crontab',
     'crontab-u',
     'csv',
+    'csv-s',
     'date',
     'df',
     'dig',
@@ -85,6 +86,7 @@ parsers = [
     'lsblk',
     'lsmod',
     'lsof',
+    'lsusb',
     'mount',
     'netstat',
     'ntpq',
