@@ -1,8 +1,10 @@
 """jc - JSON CLI output utility `ls` and `vdir` command output streaming parser
 
-This streaming parser requires the `-l` option to be used on `ls`. If there are newline characters in the filename, then make sure to use the `-b` option on `ls`.
+> This streaming parser outputs JSON Lines
 
-The `jc` `-q` option can be used to ignore parsing errors. (e.g. filenames with newline characters, but `-b` was not used)
+Requires the `-l` option to be used on `ls`. If there are newline characters in the filename, then make sure to use the `-b` option on `ls`.
+
+The `jc` `-qq` option can be used to ignore parsing errors. (e.g. filenames with newline characters, but `-b` was not used)
 
 The `epoch` calculated timestamp field is naive (i.e. based on the local time of the system the parser is run on)
 
